==> tas-1.0.3.tgz: package/examples/nodejs/index.js <==
/**
 * Examples of Tas.js
 * (c) 2017 Owen Luke
 * https://github.com/hiowenluke/tas
 * Released under the MIT License.
 */

(function(){arguments[0](
	require('../../lib')
)})

(function (tas) {

	//--------------------------------------------
	// What's Tas
	//--------------------------------------------
	// Tas simplifies code logic, making code easy to maintain.
	// Tas turns async code into sync code, avoiding callback hell,
	// and is faster and easier to use than Promise.

	// Tas can be used in Node.js and in browsers.
	// Tas is a lightweight JavaScript logic framework
	// (only 3KB gzipped), with no dependency.

	// Tas is the abbreviation of "tasks".

	// Learn more about Tas:
	// https://github.com/hiowenluke/tas

	//--------------------------------------------
	// How to use these examples
	//--------------------------------------------
	// 1. Run all examples to see how useful and powerful Tas is.
	// 2. Run one example at a time to get more details in the console.
	// 3. Read the source code of these examples to see how easy it is to use Tas.

	//--------------------------------------------
	// Let's start
	//--------------------------------------------
	require('./1.Basic-flow-control-in-Tas');
	//require('./2.Turns-async-callback-to-sync');
	//require('./3.Understand-the-order-of-Tas-tasks');
	//require('./4.Fix-callback-hell');
	//require('./5.Easier-to-use-than-Promise');
	//require('./6.Use-as-Promise.all-(and-race)');
	//require('./7.Use-as-cancelable-Promise.race');
	//require('./8.How-powerful-Tas-is');

});

==> tas-1.1.4.tgz: package/examples/nodejs/index.js <==
/**
 * Examples of Tas.js
 * (c) 2017 Owen Luke
 * https://github.com/tasjs/tas
 * Released under the MIT License.
 */

(function(){arguments[0](
	require('../../lib')
)})

(function (tas) {

	//--------------------------------------------
	// What's Tas
	//--------------------------------------------
	// Tas simplifies code logic, making code easy to maintain.
	// Tas turns async code into sync code, avoiding callback hell,
	// and is faster and easier to use than Promise.

	// Tas can be used in Node.js and in browsers.
	// Tas is a lightweight JavaScript logic framework
	// (only 3KB gzipped), with no dependency.

	// Tas is the abbreviation of "tasks".

	// Learn more about Tas:
	// https://github.com/tasjs/tas

	//--------------------------------------------
	// How to use these examples
	//--------------------------------------------
	// 1. Run all examples to see how useful and powerful Tas is.
	// 2. Run one example at a time to get more details in the console.
	// 3. Read the source code of these examples to see how easy it is to use Tas.

	//--------------------------------------------
	// Let's start
	//--------------------------------------------
	require('./1.Basic-flow-control-in-Tas');
	//require('./2.Turns-async-callback-to-sync');
	//require('./3.Understand-the-order-of-Tas-tasks');
	//require('./4.Fix-callback-hell');
	//require('./5.Easier-to-use-than-Promise');
	//require('./6.Use-as-Promise.all-(and-race)');
	//require('./7.Use-as-cancelable-Promise.race');
	//require('./8.How-powerful-Tas-is');

});
